# Welcome To PyLucas

Its a Python Func Lib from Nuhil Lucas.

要注意一下, PyPi 不允许重复上传同一个版本号, 虽然现在 1.0.0 传上去了, 但是 3.1.1 版本不能再传了, 以后要注意把发行版 bug 都修完再上传, 顺便自己的版本系列里面跳过 3.1.1, 留一点破坏新更新之后直接带着功能性大更新干到 4.0.0 吧.

艹了, 还有个事, pyproject.toml 那个文件的动态版本号出问题了, 现在实际版本号是 tm 0.0.0, 回去要改, 这下 tmd 1.0.0 的版本号用不了了....
